km3pipe.io.JPPPump
==================

.. currentmodule:: km3pipe.io

.. autoclass:: JPPPump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~JPPPump.__init__
      ~JPPPump.add
      ~JPPPump.blob_generator
      ~JPPPump.close_file
      ~JPPPump.configure
      ~JPPPump.extract_event
      ~JPPPump.extract_summaryslice_frame
      ~JPPPump.extract_timeslice_frame
      ~JPPPump.finish
      ~JPPPump.get
      ~JPPPump.next
      ~JPPPump.open_file
      ~JPPPump.pre_finish
      ~JPPPump.process
      ~JPPPump.rewind_file
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~JPPPump.name
   
   